This dataset, whooping_cough_ts, is a time series object containing annual counts of deaths from whooping cough in London from 1740 to 1881, with three measurement variables recorded each year.
data(whooping_cough_ts)A multivariate time series with 142 annual observations from 1740 to 1881 and 3 variables:
Number of whooping cough deaths (integer)
Death ratio (numeric)
Total deaths from all causes (integer)
The dataset name has been kept as 'whooping_cough_ts' to avoid confusion with other datasets in the R ecosystem. This naming convention helps distinguish this dataset as part of the PulmoDataSets package. The suffix 'ts' indicates that this is a time series object. The original content has not been modified in any way.